# Generated by roxygen2: do not edit by hand

S3method(plot,PSRWE_DTA)
S3method(plot,PSRWE_DTA_MAT)
S3method(plot,PSRWE_RST)
S3method(print,PSRWE_BOR)
S3method(print,PSRWE_DTA)
S3method(print,PSRWE_DTA_MAT)
S3method(print,PSRWE_RST)
S3method(print,PSRWE_RST_OUTANA)
S3method(summary,PSRWE_DTA)
S3method(summary,PSRWE_DTA_MAT)
S3method(summary,PSRWE_RST)
S3method(summary,PSRWE_RST_OUTANA)
export(get_distance)
export(psrwe_borrow)
export(psrwe_ci)
export(psrwe_compl)
export(psrwe_est)
export(psrwe_infer)
export(psrwe_match)
export(psrwe_outana)
export(psrwe_powerp)
export(psrwe_powerp_watt)
export(psrwe_survkm)
export(psrwe_survlrk)
export(psrwe_survrmst)
export(rwe_cl)
export(rwe_cut)
export(rwe_km)
export(rwe_lrk)
export(rwe_rmst)
export(rwe_stan)
import(Rcpp)
import(ggplot2)
import(methods)
import(rstantools)
importFrom(cowplot,plot_grid)
importFrom(dplyr,"%>%")
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,count)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,group_by_)
importFrom(dplyr,if_else)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_if)
importFrom(dplyr,n)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,summarize)
importFrom(dplyr,ungroup)
importFrom(grDevices,colors)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(parallel,detectCores)
importFrom(randomForest,randomForest)
importFrom(rstan,extract)
importFrom(rstan,rstan_options)
importFrom(rstan,sampling)
importFrom(rstan,stan_rhat)
importFrom(rstan,stanc)
importFrom(rstan,traceplot)
importFrom(stats,approxfun)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,cov)
importFrom(stats,density)
importFrom(stats,ecdf)
importFrom(stats,glm)
importFrom(stats,integrate)
importFrom(stats,ks.test)
importFrom(stats,optim)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rbeta)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(survival,Surv)
importFrom(survival,survfit)
useDynLib(psrwe, .registration = TRUE)
